# oneNeuron.pypi
oneNeuron.pypi


# reference -
[official python doc]  (https://packaging.python.org/tutorials/packaging-projects/)

[official docs for github action] (https://docs.github.com/en/actions/automating-builds-and-tests/building-and-testing-python#publishing-to-package-registries)